==> cmr-client-0.1.0-20170827.092303-5.jar: public/js/out/cmr/client/ingest/impl.js <==
// Compiled by ClojureScript 1.9.908 {}
goog.provide('cmr.client.ingest.impl');
goog.require('cljs.core');
goog.require('cmr.client.base.impl');
goog.require('cmr.client.http');

/**
* @constructor
 * @implements {cljs.core.IRecord}
 * @implements {cljs.core.IEquiv}
 * @implements {cljs.core.IHash}
 * @implements {cljs.core.ICollection}
 * @implements {cljs.core.ICounted}
 * @implements {cljs.core.ISeqable}
 * @implements {cljs.core.IMeta}
 * @implements {cljs.core.ICloneable}
 * @implements {cljs.core.IPrintWithWriter}
 * @implements {cljs.core.IIterable}
 * @implements {cljs.core.IWithMeta}
 * @implements {cljs.core.IAssociative}
 * @implements {cljs.core.IMap}
 * @implements {cljs.core.ILookup}
*/
cmr.client.ingest.impl.CMRIngestClientData = (function (endpoint,options,http_client,__meta,__extmap,__hash){
this.endpoint = endpoint;
this.options = options;
this.http_client = http_client;
this.__meta = __meta;
this.__extmap = __extmap;
this.__hash = __hash;
this.cljs$lang$protocol_mask$partition0$ = 2229667594;
this.cljs$lang$protocol_mask$partition1$ = 139264;
});
cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ILookup$_lookup$arity$2 = (function (this__28987__auto__,k__28988__auto__){
var self__ = this;
var this__28987__auto____$1 = this;
return this__28987__auto____$1.cljs$core$ILookup$_lookup$arity$3(null,k__28988__auto__,null);
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ILookup$_lookup$arity$3 = (function (this__28989__auto__,k31928,else__28990__auto__){
var self__ = this;
var this__28989__auto____$1 = this;
var G__31932 = k31928;
var G__31932__$1 = (((G__31932 instanceof cljs.core.Keyword))?G__31932.fqn:null);
switch (G__31932__$1) {
case "endpoint":
return self__.endpoint;

break;
case "options":
return self__.options;

break;
case "http-client":
return self__.http_client;

break;
default:
return cljs.core.get.call(null,self__.__extmap,k31928,else__28990__auto__);

}
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IPrintWithWriter$_pr_writer$arity$3 = (function (this__29001__auto__,writer__29002__auto__,opts__29003__auto__){
var self__ = this;
var this__29001__auto____$1 = this;
var pr_pair__29004__auto__ = ((function (this__29001__auto____$1){
return (function (keyval__29005__auto__){
return cljs.core.pr_sequential_writer.call(null,writer__29002__auto__,cljs.core.pr_writer,""," ","",opts__29003__auto__,keyval__29005__auto__);
});})(this__29001__auto____$1))
;
return cljs.core.pr_sequential_writer.call(null,writer__29002__auto__,pr_pair__29004__auto__,"#cmr.client.ingest.impl.CMRIngestClientData{",", ","}",opts__29003__auto__,cljs.core.concat.call(null,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"endpoint","endpoint",447890044),self__.endpoint],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"options","options",99638489),self__.options],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"http-client","http-client",-1812758074),self__.http_client],null))], null),self__.__extmap));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IIterable$_iterator$arity$1 = (function (G__31927){
var self__ = this;
var G__31927__$1 = this;
return (new cljs.core.RecordIter((0),G__31927__$1,3,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"endpoint","endpoint",447890044),new cljs.core.Keyword(null,"options","options",99638489),new cljs.core.Keyword(null,"http-client","http-client",-1812758074)], null),(cljs.core.truth_(self__.__extmap)?cljs.core._iterator.call(null,self__.__extmap):cljs.core.nil_iter.call(null))));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IMeta$_meta$arity$1 = (function (this__28985__auto__){
var self__ = this;
var this__28985__auto____$1 = this;
return self__.__meta;
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ICloneable$_clone$arity$1 = (function (this__28982__auto__){
var self__ = this;
var this__28982__auto____$1 = this;
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,self__.options,self__.http_client,self__.__meta,self__.__extmap,self__.__hash));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ICounted$_count$arity$1 = (function (this__28991__auto__){
var self__ = this;
var this__28991__auto____$1 = this;
return (3 + cljs.core.count.call(null,self__.__extmap));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IHash$_hash$arity$1 = (function (this__28983__auto__){
var self__ = this;
var this__28983__auto____$1 = this;
var h__28801__auto__ = self__.__hash;
if(!((h__28801__auto__ == null))){
return h__28801__auto__;
} else {
var h__28801__auto____$1 = ((function (h__28801__auto__,this__28983__auto____$1){
return (function (coll__28984__auto__){
return (-1139348313 ^ cljs.core.hash_unordered_coll.call(null,coll__28984__auto__));
});})(h__28801__auto__,this__28983__auto____$1))
.call(null,this__28983__auto____$1);
self__.__hash = h__28801__auto____$1;

return h__28801__auto____$1;
}
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (this31929,other31930){
var self__ = this;
var this31929__$1 = this;
return (!((other31930 == null))) && ((this31929__$1.constructor === other31930.constructor)) && (cljs.core._EQ_.call(null,this31929__$1.endpoint,other31930.endpoint)) && (cljs.core._EQ_.call(null,this31929__$1.options,other31930.options)) && (cljs.core._EQ_.call(null,this31929__$1.http_client,other31930.http_client)) && (cljs.core._EQ_.call(null,this31929__$1.__extmap,other31930.__extmap));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IMap$_dissoc$arity$2 = (function (this__28996__auto__,k__28997__auto__){
var self__ = this;
var this__28996__auto____$1 = this;
if(cljs.core.contains_QMARK_.call(null,new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"http-client","http-client",-1812758074),null,new cljs.core.Keyword(null,"options","options",99638489),null,new cljs.core.Keyword(null,"endpoint","endpoint",447890044),null], null), null),k__28997__auto__)){
return cljs.core.dissoc.call(null,cljs.core._with_meta.call(null,cljs.core.into.call(null,cljs.core.PersistentArrayMap.EMPTY,this__28996__auto____$1),self__.__meta),k__28997__auto__);
} else {
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,self__.options,self__.http_client,self__.__meta,cljs.core.not_empty.call(null,cljs.core.dissoc.call(null,self__.__extmap,k__28997__auto__)),null));
}
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IAssociative$_assoc$arity$3 = (function (this__28994__auto__,k__28995__auto__,G__31927){
var self__ = this;
var this__28994__auto____$1 = this;
var pred__31933 = cljs.core.keyword_identical_QMARK_;
var expr__31934 = k__28995__auto__;
if(cljs.core.truth_(pred__31933.call(null,new cljs.core.Keyword(null,"endpoint","endpoint",447890044),expr__31934))){
return (new cmr.client.ingest.impl.CMRIngestClientData(G__31927,self__.options,self__.http_client,self__.__meta,self__.__extmap,null));
} else {
if(cljs.core.truth_(pred__31933.call(null,new cljs.core.Keyword(null,"options","options",99638489),expr__31934))){
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,G__31927,self__.http_client,self__.__meta,self__.__extmap,null));
} else {
if(cljs.core.truth_(pred__31933.call(null,new cljs.core.Keyword(null,"http-client","http-client",-1812758074),expr__31934))){
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,self__.options,G__31927,self__.__meta,self__.__extmap,null));
} else {
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,self__.options,self__.http_client,self__.__meta,cljs.core.assoc.call(null,self__.__extmap,k__28995__auto__,G__31927),null));
}
}
}
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ISeqable$_seq$arity$1 = (function (this__28999__auto__){
var self__ = this;
var this__28999__auto____$1 = this;
return cljs.core.seq.call(null,cljs.core.concat.call(null,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"endpoint","endpoint",447890044),self__.endpoint],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"options","options",99638489),self__.options],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"http-client","http-client",-1812758074),self__.http_client],null))], null),self__.__extmap));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IWithMeta$_with_meta$arity$2 = (function (this__28986__auto__,G__31927){
var self__ = this;
var this__28986__auto____$1 = this;
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,self__.options,self__.http_client,G__31927,self__.__extmap,self__.__hash));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ICollection$_conj$arity$2 = (function (this__28992__auto__,entry__28993__auto__){
var self__ = this;
var this__28992__auto____$1 = this;
if(cljs.core.vector_QMARK_.call(null,entry__28993__auto__)){
return this__28992__auto____$1.cljs$core$IAssociative$_assoc$arity$3(null,cljs.core._nth.call(null,entry__28993__auto__,(0)),cljs.core._nth.call(null,entry__28993__auto__,(1)));
} else {
return cljs.core.reduce.call(null,cljs.core._conj,this__28992__auto____$1,entry__28993__auto__);
}
});

cmr.client.ingest.impl.CMRIngestClientData.getBasis = (function (){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Symbol(null,"endpoint","endpoint",2088421571,null),new cljs.core.Symbol(null,"options","options",1740170016,null),new cljs.core.Symbol(null,"http-client","http-client",-172226547,null)], null);
});

cmr.client.ingest.impl.CMRIngestClientData.cljs$lang$type = true;

cmr.client.ingest.impl.CMRIngestClientData.cljs$lang$ctorPrSeq = (function (this__29023__auto__){
return cljs.core._conj.call(null,cljs.core.List.EMPTY,"cmr.client.ingest.impl/CMRIngestClientData");
});

cmr.client.ingest.impl.CMRIngestClientData.cljs$lang$ctorPrWriter = (function (this__29023__auto__,writer__29024__auto__){
return cljs.core._write.call(null,writer__29024__auto__,"cmr.client.ingest.impl/CMRIngestClientData");
});

cmr.client.ingest.impl.__GT_CMRIngestClientData = (function cmr$client$ingest$impl$__GT_CMRIngestClientData(endpoint,options,http_client){
return (new cmr.client.ingest.impl.CMRIngestClientData(endpoint,options,http_client,null,null,null));
});

cmr.client.ingest.impl.map__GT_CMRIngestClientData = (function cmr$client$ingest$impl$map__GT_CMRIngestClientData(G__31931){
return (new cmr.client.ingest.impl.CMRIngestClientData(new cljs.core.Keyword(null,"endpoint","endpoint",447890044).cljs$core$IFn$_invoke$arity$1(G__31931),new cljs.core.Keyword(null,"options","options",99638489).cljs$core$IFn$_invoke$arity$1(G__31931),new cljs.core.Keyword(null,"http-client","http-client",-1812758074).cljs$core$IFn$_invoke$arity$1(G__31931),null,cljs.core.not_empty.call(null,cljs.core.dissoc.call(null,G__31931,new cljs.core.Keyword(null,"endpoint","endpoint",447890044),new cljs.core.Keyword(null,"options","options",99638489),new cljs.core.Keyword(null,"http-client","http-client",-1812758074))),null));
});

cmr.client.ingest.impl.get_providers = (function cmr$client$ingest$impl$get_providers(this$){
return cmr.client.http.get.call(null,new cljs.core.Keyword(null,"http-client","http-client",-1812758074).cljs$core$IFn$_invoke$arity$1(this$),cmr.client.base.impl.get_url.call(null,this$,"/providers"));
});

//# sourceMappingURL=impl.js.map?rel=1503825606745

==> cmr-client-0.1.0-20170828.041659-6.jar: public/js/out/cmr/client/ingest/impl.js <==
// Compiled by ClojureScript 1.9.908 {}
goog.provide('cmr.client.ingest.impl');
goog.require('cljs.core');
goog.require('cmr.client.http.core');
goog.require('cmr.client.base.impl');

/**
* @constructor
 * @implements {cljs.core.IRecord}
 * @implements {cljs.core.IEquiv}
 * @implements {cljs.core.IHash}
 * @implements {cljs.core.ICollection}
 * @implements {cljs.core.ICounted}
 * @implements {cljs.core.ISeqable}
 * @implements {cljs.core.IMeta}
 * @implements {cljs.core.ICloneable}
 * @implements {cljs.core.IPrintWithWriter}
 * @implements {cljs.core.IIterable}
 * @implements {cljs.core.IWithMeta}
 * @implements {cljs.core.IAssociative}
 * @implements {cljs.core.IMap}
 * @implements {cljs.core.ILookup}
*/
cmr.client.ingest.impl.CMRIngestClientData = (function (endpoint,options,http_client,__meta,__extmap,__hash){
this.endpoint = endpoint;
this.options = options;
this.http_client = http_client;
this.__meta = __meta;
this.__extmap = __extmap;
this.__hash = __hash;
this.cljs$lang$protocol_mask$partition0$ = 2229667594;
this.cljs$lang$protocol_mask$partition1$ = 139264;
});
cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ILookup$_lookup$arity$2 = (function (this__28987__auto__,k__28988__auto__){
var self__ = this;
var this__28987__auto____$1 = this;
return this__28987__auto____$1.cljs$core$ILookup$_lookup$arity$3(null,k__28988__auto__,null);
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ILookup$_lookup$arity$3 = (function (this__28989__auto__,k37966,else__28990__auto__){
var self__ = this;
var this__28989__auto____$1 = this;
var G__37970 = k37966;
var G__37970__$1 = (((G__37970 instanceof cljs.core.Keyword))?G__37970.fqn:null);
switch (G__37970__$1) {
case "endpoint":
return self__.endpoint;

break;
case "options":
return self__.options;

break;
case "http-client":
return self__.http_client;

break;
default:
return cljs.core.get.call(null,self__.__extmap,k37966,else__28990__auto__);

}
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IPrintWithWriter$_pr_writer$arity$3 = (function (this__29001__auto__,writer__29002__auto__,opts__29003__auto__){
var self__ = this;
var this__29001__auto____$1 = this;
var pr_pair__29004__auto__ = ((function (this__29001__auto____$1){
return (function (keyval__29005__auto__){
return cljs.core.pr_sequential_writer.call(null,writer__29002__auto__,cljs.core.pr_writer,""," ","",opts__29003__auto__,keyval__29005__auto__);
});})(this__29001__auto____$1))
;
return cljs.core.pr_sequential_writer.call(null,writer__29002__auto__,pr_pair__29004__auto__,"#cmr.client.ingest.impl.CMRIngestClientData{",", ","}",opts__29003__auto__,cljs.core.concat.call(null,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"endpoint","endpoint",447890044),self__.endpoint],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"options","options",99638489),self__.options],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"http-client","http-client",-1812758074),self__.http_client],null))], null),self__.__extmap));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IIterable$_iterator$arity$1 = (function (G__37965){
var self__ = this;
var G__37965__$1 = this;
return (new cljs.core.RecordIter((0),G__37965__$1,3,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"endpoint","endpoint",447890044),new cljs.core.Keyword(null,"options","options",99638489),new cljs.core.Keyword(null,"http-client","http-client",-1812758074)], null),(cljs.core.truth_(self__.__extmap)?cljs.core._iterator.call(null,self__.__extmap):cljs.core.nil_iter.call(null))));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IMeta$_meta$arity$1 = (function (this__28985__auto__){
var self__ = this;
var this__28985__auto____$1 = this;
return self__.__meta;
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ICloneable$_clone$arity$1 = (function (this__28982__auto__){
var self__ = this;
var this__28982__auto____$1 = this;
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,self__.options,self__.http_client,self__.__meta,self__.__extmap,self__.__hash));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ICounted$_count$arity$1 = (function (this__28991__auto__){
var self__ = this;
var this__28991__auto____$1 = this;
return (3 + cljs.core.count.call(null,self__.__extmap));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IHash$_hash$arity$1 = (function (this__28983__auto__){
var self__ = this;
var this__28983__auto____$1 = this;
var h__28801__auto__ = self__.__hash;
if(!((h__28801__auto__ == null))){
return h__28801__auto__;
} else {
var h__28801__auto____$1 = ((function (h__28801__auto__,this__28983__auto____$1){
return (function (coll__28984__auto__){
return (-1139348313 ^ cljs.core.hash_unordered_coll.call(null,coll__28984__auto__));
});})(h__28801__auto__,this__28983__auto____$1))
.call(null,this__28983__auto____$1);
self__.__hash = h__28801__auto____$1;

return h__28801__auto____$1;
}
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (this37967,other37968){
var self__ = this;
var this37967__$1 = this;
return (!((other37968 == null))) && ((this37967__$1.constructor === other37968.constructor)) && (cljs.core._EQ_.call(null,this37967__$1.endpoint,other37968.endpoint)) && (cljs.core._EQ_.call(null,this37967__$1.options,other37968.options)) && (cljs.core._EQ_.call(null,this37967__$1.http_client,other37968.http_client)) && (cljs.core._EQ_.call(null,this37967__$1.__extmap,other37968.__extmap));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IMap$_dissoc$arity$2 = (function (this__28996__auto__,k__28997__auto__){
var self__ = this;
var this__28996__auto____$1 = this;
if(cljs.core.contains_QMARK_.call(null,new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"http-client","http-client",-1812758074),null,new cljs.core.Keyword(null,"options","options",99638489),null,new cljs.core.Keyword(null,"endpoint","endpoint",447890044),null], null), null),k__28997__auto__)){
return cljs.core.dissoc.call(null,cljs.core._with_meta.call(null,cljs.core.into.call(null,cljs.core.PersistentArrayMap.EMPTY,this__28996__auto____$1),self__.__meta),k__28997__auto__);
} else {
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,self__.options,self__.http_client,self__.__meta,cljs.core.not_empty.call(null,cljs.core.dissoc.call(null,self__.__extmap,k__28997__auto__)),null));
}
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IAssociative$_assoc$arity$3 = (function (this__28994__auto__,k__28995__auto__,G__37965){
var self__ = this;
var this__28994__auto____$1 = this;
var pred__37971 = cljs.core.keyword_identical_QMARK_;
var expr__37972 = k__28995__auto__;
if(cljs.core.truth_(pred__37971.call(null,new cljs.core.Keyword(null,"endpoint","endpoint",447890044),expr__37972))){
return (new cmr.client.ingest.impl.CMRIngestClientData(G__37965,self__.options,self__.http_client,self__.__meta,self__.__extmap,null));
} else {
if(cljs.core.truth_(pred__37971.call(null,new cljs.core.Keyword(null,"options","options",99638489),expr__37972))){
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,G__37965,self__.http_client,self__.__meta,self__.__extmap,null));
} else {
if(cljs.core.truth_(pred__37971.call(null,new cljs.core.Keyword(null,"http-client","http-client",-1812758074),expr__37972))){
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,self__.options,G__37965,self__.__meta,self__.__extmap,null));
} else {
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,self__.options,self__.http_client,self__.__meta,cljs.core.assoc.call(null,self__.__extmap,k__28995__auto__,G__37965),null));
}
}
}
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ISeqable$_seq$arity$1 = (function (this__28999__auto__){
var self__ = this;
var this__28999__auto____$1 = this;
return cljs.core.seq.call(null,cljs.core.concat.call(null,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"endpoint","endpoint",447890044),self__.endpoint],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"options","options",99638489),self__.options],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"http-client","http-client",-1812758074),self__.http_client],null))], null),self__.__extmap));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$IWithMeta$_with_meta$arity$2 = (function (this__28986__auto__,G__37965){
var self__ = this;
var this__28986__auto____$1 = this;
return (new cmr.client.ingest.impl.CMRIngestClientData(self__.endpoint,self__.options,self__.http_client,G__37965,self__.__extmap,self__.__hash));
});

cmr.client.ingest.impl.CMRIngestClientData.prototype.cljs$core$ICollection$_conj$arity$2 = (function (this__28992__auto__,entry__28993__auto__){
var self__ = this;
var this__28992__auto____$1 = this;
if(cljs.core.vector_QMARK_.call(null,entry__28993__auto__)){
return this__28992__auto____$1.cljs$core$IAssociative$_assoc$arity$3(null,cljs.core._nth.call(null,entry__28993__auto__,(0)),cljs.core._nth.call(null,entry__28993__auto__,(1)));
} else {
return cljs.core.reduce.call(null,cljs.core._conj,this__28992__auto____$1,entry__28993__auto__);
}
});

cmr.client.ingest.impl.CMRIngestClientData.getBasis = (function (){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Symbol(null,"endpoint","endpoint",2088421571,null),new cljs.core.Symbol(null,"options","options",1740170016,null),new cljs.core.Symbol(null,"http-client","http-client",-172226547,null)], null);
});

cmr.client.ingest.impl.CMRIngestClientData.cljs$lang$type = true;

cmr.client.ingest.impl.CMRIngestClientData.cljs$lang$ctorPrSeq = (function (this__29023__auto__){
return cljs.core._conj.call(null,cljs.core.List.EMPTY,"cmr.client.ingest.impl/CMRIngestClientData");
});

cmr.client.ingest.impl.CMRIngestClientData.cljs$lang$ctorPrWriter = (function (this__29023__auto__,writer__29024__auto__){
return cljs.core._write.call(null,writer__29024__auto__,"cmr.client.ingest.impl/CMRIngestClientData");
});

cmr.client.ingest.impl.__GT_CMRIngestClientData = (function cmr$client$ingest$impl$__GT_CMRIngestClientData(endpoint,options,http_client){
return (new cmr.client.ingest.impl.CMRIngestClientData(endpoint,options,http_client,null,null,null));
});

cmr.client.ingest.impl.map__GT_CMRIngestClientData = (function cmr$client$ingest$impl$map__GT_CMRIngestClientData(G__37969){
return (new cmr.client.ingest.impl.CMRIngestClientData(new cljs.core.Keyword(null,"endpoint","endpoint",447890044).cljs$core$IFn$_invoke$arity$1(G__37969),new cljs.core.Keyword(null,"options","options",99638489).cljs$core$IFn$_invoke$arity$1(G__37969),new cljs.core.Keyword(null,"http-client","http-client",-1812758074).cljs$core$IFn$_invoke$arity$1(G__37969),null,cljs.core.not_empty.call(null,cljs.core.dissoc.call(null,G__37969,new cljs.core.Keyword(null,"endpoint","endpoint",447890044),new cljs.core.Keyword(null,"options","options",99638489),new cljs.core.Keyword(null,"http-client","http-client",-1812758074))),null));
});

cmr.client.ingest.impl.get_providers = (function cmr$client$ingest$impl$get_providers(this$){
return cmr.client.http.core.get.call(null,new cljs.core.Keyword(null,"http-client","http-client",-1812758074).cljs$core$IFn$_invoke$arity$1(this$),cmr.client.base.impl.get_url.call(null,this$,"/providers"));
});

//# sourceMappingURL=impl.js.map?rel=1503892841232
